
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.030.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "Catmandu modules for working with solr endpoints",
  "dist_author" => [
    "Nicolas Steenlant, C<< nicolas.steenlant at ugent.be >>"
  ],
  "dist_name" => "Catmandu-Solr",
  "dist_version" => "0.0212",
  "license" => "perl",
  "module_name" => "Catmandu::Solr",
  "recommends" => {},
  "recursive_test_files" => 1,
  "requires" => {
    "CQL::Parser" => "1.12",
    "Catmandu" => "0.7",
    "Moo" => "1.00",
    "WebService::Solr" => "0.16",
    "perl" => "v5.10.1"
  },
  "script_files" => [],
  "test_requires" => {
    "Software::License" => 0,
    "Test::Exception" => 0,
    "Test::More" => 0
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Software::License" => 0,
  "Test::Exception" => 0,
  "Test::More" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);

$build->create_build_script;
